<h1 align="center">🚧 WIP / 在制品 🚧</h1>

<p align="center">
  <a href="https://github.com/A-kirami/flowery">
    <br />
    <img src="./assets/flowery-logo.svg" alt="Flowery Logo" width="160" />
    <br />
    <picture>
      <source media="(prefers-color-scheme: dark)" srcset="./assets/flowery-text-dark.svg">
      <source media="(prefers-color-scheme: light)" srcset="./assets/flowery-text-light.svg">
      <img src="./public/flowery-text-light.svg" alt="Flowery Text" width="160" />
    </picture>
  </a>
  <br />
  专注绘图的 Python 图像处理库
</p>

## 📄 许可证

Code: MIT, 2023, Akirami

Logo: CC-BY-NC-ND, Designs by Akirami
